/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.asset.display.internal.contributor.field;

import com.liferay.asset.display.contributor.AssetDisplayContributorField;
import com.liferay.info.display.contributor.field.InfoDisplayContributorField;
import com.liferay.portal.kernel.util.HashMapDictionary;

import java.util.List;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.FrameworkUtil;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferenceCardinality;
import org.osgi.service.component.annotations.ReferencePolicy;

/**
 * @author Jürgen Kappler
 */
@Component(
	immediate = true, service = AssetDisplayContributorFieldTracker.class
)
public class AssetDisplayContributorFieldTracker {

	@Reference(
		cardinality = ReferenceCardinality.MULTIPLE,
		policy = ReferencePolicy.DYNAMIC
	)
	protected void setAssetDisplayContributorField(
		AssetDisplayContributorField assetDisplayContributorField,
		Map<String, Object> properties) {

		Bundle bundle = FrameworkUtil.getBundle(
			assetDisplayContributorField.getClass());

		BundleContext bundleContext = bundle.getBundleContext();

		ServiceRegistration<InfoDisplayContributorField> serviceRegistration =
			bundleContext.registerService(
				InfoDisplayContributorField.class,
				new AssetInfoDisplayContributorFieldAdapter(
					assetDisplayContributorField),
				new HashMapDictionary<>(properties));

		_serviceRegistrations.add(serviceRegistration);
	}

	protected void unsetAssetDisplayContributorField(
		AssetDisplayContributorField assetDisplayContributorField) {

		_serviceRegistrations.remove(assetDisplayContributorField);
	}

	private final List<ServiceRegistration<InfoDisplayContributorField>>
		_serviceRegistrations = new CopyOnWriteArrayList<>();

}